;;; make a beep
(define (beep) (display "\a"))

;;; feel for prize (wrapper)
(define (feel-prize)
;  (display "feeling for prize..\n")
  (robot-feel "prize")
)

;;; grab all prizes
(define (grab-all-prizes)
  (do () ((not (eqv? (feel-prize) #t))) (grab-prize))
)

;;; grab a single prize
(define (grab-prize)
;  (display "grabbing for prize..\n")
  (robot-grab)
;  (display "moving one space..\n")
  (robot-move 1)
)

;;; hunt for all prizes

(grab-all-prizes)
(sleep 1)
(robot-turn 1)

(grab-all-prizes)
(sleep 1)
(robot-turn 1)

(grab-all-prizes)
(sleep 1)
(robot-turn 1)

(grab-all-prizes)
